@@ -17,7 +17,7 @@ pub struct Stream {
 #[derive(Eq, PartialEq)]
 pub enum StreamError {
     EOF,
-    ZeroLength
+    ZeroLength,
 }
 
 impl Stream {
@@ -104,10 +104,36 @@ impl Stream {
         buffer.len()
     }
 
+    /// Skip "count" bytes in stream. Return skipped bytes count.
+    pub fn skip(&mut self, count: usize) -> usize {
+        let count = min(count, self.available());
+        self.position += count;
+        count
+    }
+
+    /// Skip all bytes in stream. Return skipped bytes count.
+    pub fn skip_all(&mut self) -> usize {
+        let count = self.available();
+        self.position += count;
+        count
+    }
+
+    /// View of available bytes in stream.
+    pub fn view(&self) -> &[u8] {
+        &self.data[self.position..]
+    }
+
     /// Clear bytes that have been read. Has no effect on the allocated capacity.
     pub fn truncate_readied(&mut self) {
+        if self.position == self.data.len() {
+            self.position = 0;
+            self.data.clear();
+            return;
+        }
         if self.position > 0 {
-            self.data.copy_within(self.position..,0);
+            let size = self.available();
+            self.data.copy_within(self.position.., 0);
+            self.data.resize(size, 0);
             self.position = 0;
         }
     }
