@@ -1,4 +1,4 @@
-use crate::{Stream, StreamError};
+use crate::{Stream};
 
 #[test]
 fn it_works() {
@@ -7,7 +7,7 @@ fn it_works() {
     stream.write(&arr[2..6]);
     assert_eq!(stream.available(), 4);
     let mut dest = [0; 10];
-    stream.read(&mut dest);
+    stream.read(&mut dest).ok();
     assert_eq!(dest, [3, 4, 5, 6, 0, 0, 0, 0, 0, 0]);
     assert_eq!(stream.available(), 0);
     assert_eq!(2 + 2, 4);
