@@ -46,6 +46,21 @@ impl<'a> Reader<'a> {
         self.stream.read(buffer)
     }
 
+    /// Skip "count" bytes in stream. Return skipped bytes count.
+    pub fn skip(&mut self, count: usize) -> usize {
+        self.stream.skip(count)
+    }
+
+    /// Skip all bytes in stream. Return skipped bytes count.
+    pub fn skip_all(&mut self) -> usize {
+        self.stream.skip_all()
+    }
+
+    /// View of available bytes in stream.
+    pub fn view(&self) -> &[u8] {
+        self.stream.view()
+    }
+
     /// Return available to read bytes.
     pub fn available(&self) -> usize {
         self.stream.available()
